@@ -104,7 +104,6 @@ utf8_wordcomplete_open (GokWordComplete *complete, const gchar *directory)
 {
 	gchar *contents;
 	gchar **dictionary_lines = NULL;
-	gint i;
 	GError *error = NULL;
 	GokUTF8WordComplete *utf8_complete = GOK_UTF8WORDCOMPLETE (complete);
 
@@ -133,7 +132,7 @@ utf8_wordcomplete_open (GokWordComplete *complete, const gchar *directory)
 
 	g_free (contents);
 
-	if (dictionary_lines == NULL) 
+	if (dictionary_lines == NULL || dictionary_lines[0] == NULL) 
 	{
 		return FALSE;
 	}
@@ -165,7 +164,7 @@ utf8_wordcomplete_open (GokWordComplete *complete, const gchar *directory)
 	/* create gunichar hash for looking up search entry points */
 	utf8_wordcomplete_create_unicode_hash (utf8_complete);
 
-	fprintf (stderr, "Word prediction dictionary contains a total of %d words\n", 
+	gok_log ("Word prediction dictionary contains a total of %d words\n", 
 		 g_list_length (utf8_complete->word_list));
 
 	return TRUE;
@@ -215,10 +214,9 @@ utf8_wordcomplete_predict_string (GokWordComplete *complete, const gchar* word,
 {
 	gchar **word_predict_list;
 	gchar *normalized, *tmp;
-	gint  i, n, m = num_predictions;
+	gint  n;
 	GList *predictions;
 	GokUTF8WordComplete *utf8_complete = GOK_UTF8WORDCOMPLETE (complete);
-	gpointer data;
 	
 	/* validate the given values */
 	if (word == NULL || num_predictions < 1)
@@ -650,10 +648,11 @@ utf8_add_to_list_from_lines (GList *list, gchar **lines, gboolean read_freqs, gb
 			}
 			if (string)
 			{
-				string = g_utf8_normalize (string, -1, G_NORMALIZE_DEFAULT_COMPOSE); /* this allocs a new string */
+				char *predict_string = g_utf8_normalize (string, -1, G_NORMALIZE_DEFAULT_COMPOSE); /* this allocs a new string */
 				priority = (read_freqs && tokens && tokens[0] && tokens[1]) ? 
 					g_ascii_strtod (tokens[1], NULL) : DEFAULT_INITIAL_FREQUENCY;
-				prediction = utf8_word_prediction_new (string, priority, in_primary);
+				prediction = utf8_word_prediction_new (predict_string, priority, in_primary);
+				g_free (predict_string);
 				/* prepend is much faster than append */
 				list = g_list_prepend (list, prediction);
 			}
